@@ -34,14 +34,15 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <set>
 #include <deque>
 #include <vector>
+#include <string>
 
 
 #include "c_types/ii_t_rt.h"
-#include "cpp_common/basePath_SSEC.hpp"
+#include "cpp_common/path.hpp"
 #include "cpp_common/rule.hpp"
 
 
-typedef struct ArrayType ArrayType;
+using ArrayType = struct ArrayType;
 
 namespace pgrouting {
 
@@ -49,13 +50,6 @@ class Path;
 
 namespace utilities {
 
-#if 1
-std::map<int64_t, std::set<int64_t>>
-get_combinations(const II_t_rt *, size_t);
-
-std::map<int64_t, std::set<int64_t>>
-get_combinations(int64_t*, size_t, int64_t*, size_t);
-#endif
 
 std::map<int64_t, std::set<int64_t>>
 get_combinations(
@@ -65,6 +59,8 @@ get_combinations(
 std::map<int64_t, std::set<int64_t>>
 get_combinations(const std::vector<II_t_rt>&);
 
+std::map<int64_t, std::set<int64_t>>
+get_combinations(const std::string&, ArrayType*, ArrayType*, bool, bool&);
 
 std::map<int64_t, std::set<int64_t>>
 get_combinations(const char*, ArrayType*, ArrayType*, bool);
