@@ -40,7 +40,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <boost/random/random_number_generator.hpp>
 #include <boost/graph/graph_traits.hpp>
 
-#include "cpp_common/basePath_SSEC.hpp"
+#include "cpp_common/path.hpp"
 #include "cpp_common/pgr_base_graph.hpp"
 #include "cpp_common/interruption.hpp"
 
@@ -92,8 +92,8 @@ class Pgr_randomSpanningTree {
              log << "Unknown exception caught";
          }
 
-         std::vector< SpanTree_rt > resul;
-         return resul;
+         std::vector< SpanTree_rt > result;
+         return result;
 #if 0
          std::vector< SpanTree_rt > results;
          double totalcost = 0;
