@@ -42,9 +42,9 @@ CREATE FUNCTION _pgr_floydWarshall(
     OUT agg_cost FLOAT)
 RETURNS SETOF RECORD AS
 'MODULE_PATHNAME'
-LANGUAGE C VOLATILE STRICT;
+LANGUAGE C VOLATILE STRICT
+COST ${COST_HIGH} ROWS ${ROWS_HIGH};
 
--- COMMENTS
 
 COMMENT ON FUNCTION _pgr_floydWarshall(TEXT, BOOLEAN)
 IS 'pgRouting internal function';
