@@ -30,7 +30,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 -----------------------------
 
 
---v2.6
+--v3.0
 CREATE FUNCTION pgr_bdAstarCostMatrix(
     TEXT,     -- edges sql (required)
     ANYARRAY, -- vids (required)
@@ -48,9 +48,8 @@ $BODY$
     SELECT a.start_vid, a.end_vid, a.agg_cost
     FROM _pgr_bdAstar(_pgr_get_statement($1), $2::BIGINT[], $2::BIGINT[], $3, $4, $5::FLOAT, $6::FLOAT, true) a;
 $BODY$
-LANGUAGE SQL VOLATILE
-COST 100
-ROWS 1000;
+LANGUAGE SQL VOLATILE STRICT
+COST ${COST_HIGH} ROWS ${ROWS_HIGH};
 
 
 -- COMMENT
