@@ -1,14 +1,15 @@
 /*PGR-GNU*****************************************************************
+File: _dijkstra.sql
 
 Copyright (c) 2015 pgRouting developers
 Mail: project@pgrouting.org
 
 Copyright (c) 2015 Celia Virginia Vergara Castillo
-mail: vicky_vergara@hotmail.com
+mail: vicky at erosion.dev
 
 Copyright (c) 2020 The combinations_sql signature is added by Mahmoud SAKR
 and Esteban ZIMANYI
-mail: m_attia_sakr@yahoo.com, estebanzimanyi@gmail.com
+mail: m_attia_sakr at yahoo.com, estebanzimanyi at gmail.com
 
 ------
 
@@ -28,22 +29,20 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
  ********************************************************************PGR-GNU*/
 
----------------
----------------
--- dijkstra
----------------
----------------
+--v4.0
+CREATE FUNCTION _pgr_dijkstra_v4(
+    TEXT, -- edges
 
---v3.2
-CREATE FUNCTION _pgr_dijkstra(
-    edges_sql TEXT,
-    start_vids ANYARRAY,
-    end_vids ANYARRAY,
-    directed BOOLEAN,
-    only_cost BOOLEAN,
-    normal BOOLEAN,
-    n_goals BIGINT,
-    global BOOLEAN,
+    ANYARRAY, -- departures
+    ANYARRAY, -- arrivals
+
+    BOOLEAN, --directed
+
+    BOOLEAN, -- only_cost
+    BOOLEAN, -- normal
+
+    BIGINT,  -- n_goals
+    BOOLEAN, -- global
 
     OUT seq INTEGER,
     OUT path_seq INTEGER,
@@ -55,17 +54,20 @@ CREATE FUNCTION _pgr_dijkstra(
     OUT agg_cost FLOAT)
 RETURNS SETOF RECORD AS
 'MODULE_PATHNAME'
-LANGUAGE C VOLATILE STRICT;
+LANGUAGE C VOLATILE STRICT
+COST ${COST_HIGH} ROWS ${ROWS_HIGH};
 
 
---v3.2
-CREATE FUNCTION _pgr_dijkstra(
-    edges_sql TEXT,
-    combinations_sql TEXT,
-    directed BOOLEAN,
-    only_cost BOOLEAN,
-    n_goals BIGINT,
-    global BOOLEAN,
+--v4.0
+CREATE FUNCTION _pgr_dijkstra_v4(
+    TEXT, -- edges
+    TEXT, -- combinations
+
+    BOOLEAN, --directed
+    BOOLEAN, -- only_cost
+
+    BIGINT,  -- n_goals
+    BOOLEAN, -- global
 
     OUT seq INTEGER,
     OUT path_seq INTEGER,
@@ -77,65 +79,12 @@ CREATE FUNCTION _pgr_dijkstra(
     OUT agg_cost FLOAT)
 RETURNS SETOF RECORD AS
 'MODULE_PATHNAME'
-LANGUAGE C VOLATILE STRICT;
+LANGUAGE C VOLATILE STRICT
+COST ${COST_HIGH} ROWS ${ROWS_HIGH};
 
--- COMMENTS
 
-COMMENT ON FUNCTION _pgr_dijkstra(TEXT, ANYARRAY, ANYARRAY, BOOLEAN, BOOLEAN, BOOLEAN, BIGINT, BOOLEAN)
+COMMENT ON FUNCTION _pgr_dijkstra_v4(TEXT, ANYARRAY, ANYARRAY, BOOLEAN, BOOLEAN, BOOLEAN, BIGINT, BOOLEAN)
 IS 'pgRouting internal function';
 
-COMMENT ON FUNCTION _pgr_dijkstra(TEXT, TEXT, BOOLEAN, BOOLEAN, BIGINT, BOOLEAN)
-IS 'pgRouting internal function';
-
-
-/** The following are kept for backward compatibility on signatures **/
---v3.0
-CREATE FUNCTION _pgr_dijkstra(
-    edges_sql TEXT,
-    start_vids ANYARRAY,
-    end_vids ANYARRAY,
-    directed BOOLEAN DEFAULT true,
-    only_cost BOOLEAN DEFAULT false,
-    normal BOOLEAN DEFAULT true,
-    n_goals BIGINT DEFAULT 0,
-
-    OUT seq INTEGER,
-    OUT path_seq INTEGER,
-    OUT start_vid BIGINT,
-    OUT end_vid BIGINT,
-    OUT node BIGINT,
-    OUT edge BIGINT,
-    OUT cost FLOAT,
-    OUT agg_cost FLOAT)
-RETURNS SETOF RECORD AS
-'MODULE_PATHNAME'
-LANGUAGE C VOLATILE STRICT;
-
-
---v3.1
-CREATE FUNCTION _pgr_dijkstra(
-    edges_sql TEXT,
-    combinations_sql TEXT,
-    directed BOOLEAN DEFAULT true,
-    only_cost BOOLEAN DEFAULT false,
-    normal BOOLEAN DEFAULT true,
-
-    OUT seq INTEGER,
-    OUT path_seq INTEGER,
-    OUT start_vid BIGINT,
-    OUT end_vid BIGINT,
-    OUT node BIGINT,
-    OUT edge BIGINT,
-    OUT cost FLOAT,
-    OUT agg_cost FLOAT)
-RETURNS SETOF RECORD AS
-'MODULE_PATHNAME'
-LANGUAGE C VOLATILE STRICT;
-
--- COMMENTS
-
-COMMENT ON FUNCTION _pgr_dijkstra(TEXT, ANYARRAY, ANYARRAY, BOOLEAN, BOOLEAN, BOOLEAN, BIGINT)
-IS 'pgRouting internal function';
-
-COMMENT ON FUNCTION _pgr_dijkstra(TEXT, TEXT, BOOLEAN, BOOLEAN, BOOLEAN)
+COMMENT ON FUNCTION _pgr_dijkstra_v4(TEXT, TEXT, BOOLEAN, BOOLEAN, BIGINT, BOOLEAN)
 IS 'pgRouting internal function';
