@@ -1,15 +1,15 @@
 /*PGR-GNU*****************************************************************
+File: dijkstra.sql
 
 Copyright (c) 2015 pgRouting developers
 Mail: project@pgrouting.org
 
-Copyright (c) 2022 Celia Virginia Vergara Castillo
-Copyright (c) 2015 Celia Virginia Vergara Castillo
-mail: vicky_vergara@hotmail.com
+Copyright (c) 2025 Celia Virginia Vergara Castillo
+Mail: vicky at erosion.dev
 
 Copyright (c) 2020 The combinations_sql signature is added by Mahmoud SAKR
 and Esteban ZIMANYI
-mail: m_attia_sakr@yahoo.com, estebanzimanyi@gmail.com
+Mail: m_attia_sakr at yahoo.com, estebanzimanyi at gmail.com
 
 ------
 
@@ -29,16 +29,12 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
  ********************************************************************PGR-GNU*/
 
----------------
--- pgr_dijkstra
----------------
-
 -- ONE to ONE
---v2.6
+--v3.0
 CREATE FUNCTION pgr_dijkstra(
     TEXT,   -- edges_sql (required)
-    BIGINT, -- from_vid (required)
-    BIGINT, -- to_vid (required)
+    BIGINT, -- start_vid (required)
+    BIGINT, -- end_vid (required)
 
     directed BOOLEAN DEFAULT true,
 
@@ -53,18 +49,18 @@ CREATE FUNCTION pgr_dijkstra(
 RETURNS SETOF RECORD AS
 $BODY$
     SELECT seq, path_seq, start_vid, end_vid, node, edge, cost, agg_cost
-    FROM _pgr_dijkstra(_pgr_get_statement($1), ARRAY[$2]::BIGINT[], ARRAY[$3]::BIGINT[], $4, false, true, 0, false);
+    FROM _pgr_dijkstra_v4(_pgr_get_statement($1), ARRAY[$2]::BIGINT[], ARRAY[$3]::BIGINT[],
+        $4, false, true, 0, false);
 $BODY$
-LANGUAGE sql VOLATILE STRICT
-COST 100
-ROWS 1000;
+LANGUAGE SQL VOLATILE STRICT
+COST ${COST_HIGH} ROWS ${ROWS_HIGH};
 
--- ONE to MANY
---v2.6
+-- ONE TO MANY
+--v3.0
 CREATE FUNCTION pgr_dijkstra(
     TEXT,     -- edges_sql (required)
-    BIGINT,   -- from_vid (required)
-    ANYARRAY, -- to_vids (required)
+    BIGINT,   -- start_vid (required)
+    ANYARRAY, -- end_vid (required)
 
     directed BOOLEAN DEFAULT true,
 
@@ -79,18 +75,18 @@ CREATE FUNCTION pgr_dijkstra(
 RETURNS SETOF RECORD AS
 $BODY$
     SELECT seq, path_seq, start_vid, end_vid, node, edge, cost, agg_cost
-    FROM _pgr_dijkstra(_pgr_get_statement($1), ARRAY[$2]::BIGINT[], $3::BIGINT[], $4, false, true, 0, false);
+    FROM _pgr_dijkstra_v4(_pgr_get_statement($1), ARRAY[$2]::BIGINT[], $3::BIGINT[],
+       $4, false, true, 0, false);
 $BODY$
-LANGUAGE sql VOLATILE STRICT
-COST 100
-ROWS 1000;
+LANGUAGE SQL VOLATILE STRICT
+COST ${COST_HIGH} ROWS ${ROWS_HIGH};
 
--- MANY to ONE
---v2.6
+-- MANY TO ONE
+--v3.0
 CREATE FUNCTION pgr_dijkstra(
     TEXT,     -- edges_sql (required)
-    ANYARRAY, -- from_vids (required)
-    BIGINT,   -- to_vid (required)
+    ANYARRAY, -- start_vid (required)
+    BIGINT,   -- end_vid (required)
 
     directed BOOLEAN DEFAULT true,
 
@@ -105,18 +101,18 @@ CREATE FUNCTION pgr_dijkstra(
 RETURNS SETOF RECORD AS
 $BODY$
     SELECT seq, path_seq, start_vid, end_vid, node, edge, cost, agg_cost
-    FROM _pgr_dijkstra(_pgr_get_statement($1), $2::BIGINT[], ARRAY[$3]::BIGINT[], $4, false, false, 0, false);
+    FROM _pgr_dijkstra_v4(_pgr_get_statement($1), $2::BIGINT[], ARRAY[$3]::BIGINT[],
+$4, false, false, 0, false);
 $BODY$
-LANGUAGE sql VOLATILE STRICT
-COST 100
-ROWS 1000;
+LANGUAGE SQL VOLATILE STRICT
+COST ${COST_HIGH} ROWS ${ROWS_HIGH};
 
--- MANY to MANY
---v2.6
+-- MANY TO MANY
+--v3.0
 CREATE FUNCTION pgr_dijkstra(
     TEXT,     -- edges_sql (required)
-    ANYARRAY, -- from_vids (required)
-    ANYARRAY, -- to_vids (required)
+    ANYARRAY, -- start_vid (required)
+    ANYARRAY, -- end_vid (required)
 
     directed BOOLEAN DEFAULT true,
 
@@ -131,11 +127,11 @@ CREATE FUNCTION pgr_dijkstra(
 RETURNS SETOF RECORD AS
 $BODY$
     SELECT seq, path_seq, start_vid, end_vid, node, edge, cost, agg_cost
-    FROM _pgr_dijkstra(_pgr_get_statement($1), $2::BIGINT[], $3::BIGINT[], $4, false, true, 0, false);
+    FROM _pgr_dijkstra_v4(_pgr_get_statement($1), $2::BIGINT[], $3::BIGINT[],
+      $4, false, true, 0, false);
 $BODY$
-LANGUAGE sql VOLATILE STRICT
-COST 100
-ROWS 1000;
+LANGUAGE SQL VOLATILE STRICT
+COST ${COST_HIGH} ROWS ${ROWS_HIGH};
 
 -- Combinations SQL signature
 --v3.1
@@ -156,14 +152,13 @@ CREATE FUNCTION pgr_dijkstra(
 RETURNS SETOF RECORD AS
 $BODY$
     SELECT seq, path_seq, start_vid, end_vid, node, edge, cost, agg_cost
-    FROM _pgr_dijkstra(_pgr_get_statement($1), _pgr_get_statement($2), $3, false, 0, false);
+    FROM _pgr_dijkstra_v4(_pgr_get_statement($1), _pgr_get_statement($2),
+      $3, false, 0, false);
 $BODY$
-LANGUAGE sql VOLATILE STRICT
-COST 100
-ROWS 1000;
+LANGUAGE SQL VOLATILE STRICT
+COST ${COST_HIGH} ROWS ${ROWS_HIGH};
 
 
--- COMMENTS
 
 COMMENT ON FUNCTION pgr_dijkstra(TEXT, BIGINT, BIGINT, BOOLEAN)
 IS 'pgr_dijkstra(One to One)
