@@ -5,7 +5,7 @@ Copyright (c) 2015 pgRouting developers
 Mail: project@pgrouting.org
 
 Copyright (c) 2016 Andrea Nardelli
-mail: nrd.nardelli@gmail.com
+mail: nrd.nardelli at gmail.com
 
 ------
 
@@ -25,25 +25,14 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
  ********************************************************************PGR-GNU*/
 
---------------------------
--- pgr_maxCardinalityMatch
----------------------------
-
-
---v3.0
-CREATE FUNCTION _pgr_maxCardinalityMatch(
+--v4.0
+CREATE FUNCTION _pgr_maxCardinalityMatch_v4(
     edges_sql TEXT,
-    directed BOOLEAN,
-
-    OUT seq INTEGER,
-    OUT edge BIGINT,
-    OUT source BIGINT,
-    OUT target BIGINT)
-RETURNS SETOF RECORD AS
+    OUT edge BIGINT)
+RETURNS SETOF BIGINT AS
 'MODULE_PATHNAME'
-LANGUAGE c VOLATILE STRICT;
+LANGUAGE C VOLATILE STRICT
+COST ${COST_HIGH} ROWS ${ROWS_HIGH};
 
--- COMMENTS
-
-COMMENT ON FUNCTION _pgr_maxCardinalityMatch(TEXT, BOOLEAN)
+COMMENT ON FUNCTION _pgr_maxCardinalityMatch_v4(TEXT)
 IS 'pgRouting internal function';
