@@ -30,7 +30,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 
 -- ONE to ONE
---v2.6
+--v3.0
 CREATE FUNCTION pgr_boykovKolmogorov(
     TEXT, -- edges_sql (required)
     BIGINT, -- from_vid (required)
@@ -47,11 +47,12 @@ CREATE FUNCTION pgr_boykovKolmogorov(
         SELECT seq, edge_id, source, target, flow, residual_capacity
         FROM _pgr_maxflow(_pgr_get_statement($1), ARRAY[$2]::BIGINT[], ARRAY[$3]::BIGINT[], 2);
   $BODY$
-  LANGUAGE sql VOLATILE STRICT;
+  LANGUAGE SQL VOLATILE STRICT
+COST ${COST_HIGH} ROWS ${ROWS_HIGH};
 
 
 -- ONE to MANY
---v2.6
+--v3.0
 CREATE FUNCTION pgr_boykovKolmogorov(
     TEXT, -- edges_sql (required)
     BIGINT, -- from_vid (required)
@@ -68,11 +69,12 @@ CREATE FUNCTION pgr_boykovKolmogorov(
         SELECT seq, edge_id, source, target, flow, residual_capacity
         FROM _pgr_maxflow(_pgr_get_statement($1), ARRAY[$2]::BIGINT[], $3::BIGINT[], 2);
   $BODY$
-  LANGUAGE sql VOLATILE STRICT;
+  LANGUAGE SQL VOLATILE STRICT
+COST ${COST_HIGH} ROWS ${ROWS_HIGH};
 
 
 -- MANY to ONE
---v2.6
+--v3.0
 CREATE FUNCTION pgr_boykovKolmogorov(
     TEXT, -- edges_sql (required)
     ANYARRAY, -- from_vids (required)
@@ -89,11 +91,12 @@ CREATE FUNCTION pgr_boykovKolmogorov(
         SELECT seq, edge_id, source, target, flow, residual_capacity
         FROM _pgr_maxflow(_pgr_get_statement($1), $2::BIGINT[], ARRAY[$3]::BIGINT[], 2);
   $BODY$
-  LANGUAGE sql VOLATILE STRICT;
+  LANGUAGE SQL VOLATILE STRICT
+COST ${COST_HIGH} ROWS ${ROWS_HIGH};
 
 
 -- MANY to MANY
---v2.6
+--v3.0
 CREATE FUNCTION pgr_boykovKolmogorov(
     TEXT, -- edges_sql (required)
     ANYARRAY, -- from_vids (required)
@@ -110,7 +113,8 @@ CREATE FUNCTION pgr_boykovKolmogorov(
         SELECT seq, edge_id, source, target, flow, residual_capacity
         FROM _pgr_maxflow(_pgr_get_statement($1), $2::BIGINT[], $3::BIGINT[], 2);
   $BODY$
-  LANGUAGE sql VOLATILE STRICT;
+  LANGUAGE SQL VOLATILE STRICT
+COST ${COST_HIGH} ROWS ${ROWS_HIGH};
 
 
 -- COMBINATIONS
@@ -130,10 +134,10 @@ CREATE FUNCTION pgr_boykovKolmogorov(
         SELECT seq, edge_id, source, target, flow, residual_capacity
         FROM _pgr_maxflow(_pgr_get_statement($1), _pgr_get_statement($2), 2);
   $BODY$
-  LANGUAGE sql VOLATILE STRICT;
+  LANGUAGE SQL VOLATILE STRICT
+COST ${COST_HIGH} ROWS ${ROWS_HIGH};
 
 
--- COMMENTS
 
 
 COMMENT ON FUNCTION pgr_boykovKolmogorov(TEXT, BIGINT, BIGINT)
