@@ -5,7 +5,7 @@ Copyright (c) 2015 pgRouting developers
 Mail: project@pgrouting.org
 
 Copyright (c) 2016 Andrea Nardelli
-mail: nrd.nardelli@gmail.com
+mail: nrd.nardelli at gmail.com
 
 ------
 
@@ -33,38 +33,10 @@ CREATE FUNCTION pgr_maxCardinalityMatch(
 RETURNS SETOF BIGINT AS
 $BODY$
 SELECT edge
-FROM _pgr_maxCardinalityMatch(_pgr_get_statement($1), false)
+FROM _pgr_maxCardinalityMatch_v4(_pgr_get_statement($1));
 $BODY$
 LANGUAGE SQL VOLATILE STRICT
-COST 100
-ROWS 1000;
-
---v3.4
-CREATE FUNCTION pgr_maxCardinalityMatch(
-  TEXT, -- edges_sql (required)
-
-  directed BOOLEAN,
-
-  OUT seq INTEGER,
-  OUT edge BIGINT,
-  OUT source BIGINT,
-  OUT target BIGINT)
-RETURNS SETOF RECORD AS
-$BODY$
-BEGIN
-RAISE WARNING 'pgr_maxCardinalityMatch(text,boolean) deprecated signature on v3.4.0';
-RETURN QUERY SELECT a.seq, a.edge, a.source, a.target
-FROM _pgr_maxCardinalityMatch(_pgr_get_statement($1), $2) AS a;
-END
-$BODY$
-LANGUAGE plpgsql VOLATILE STRICT
-COST 100
-ROWS 1000;
-
--- COMMENTS
-COMMENT ON FUNCTION pgr_maxCardinalityMatch(TEXT, BOOLEAN)
-IS 'pgr_maxCardinalityMatch deprecated signature on v3.4.0
-- Documentation: ${PROJECT_DOC_LINK}/pgr_maxCardinalityMatch.html';
+COST ${COST_HIGH} ROWS ${ROWS_HIGH};
 
 COMMENT ON FUNCTION pgr_maxCardinalityMatch(TEXT)
 IS 'pgr_maxCardinalityMatch
