@@ -41,9 +41,9 @@ CREATE FUNCTION _pgr_betweennessCentrality(
     OUT centrality FLOAT)
 RETURNS SETOF RECORD AS
 'MODULE_PATHNAME'
-LANGUAGE C VOLATILE STRICT;
+LANGUAGE C VOLATILE STRICT
+COST ${COST_HIGH} ROWS ${ROWS_HIGH};
 
--- COMMENTS
 
 COMMENT ON FUNCTION _pgr_betweennessCentrality(TEXT, BOOLEAN)
 IS 'pgRouting internal function';
