@@ -37,9 +37,9 @@ CREATE FUNCTION _pgr_topologicalSort(
     OUT sorted_v BIGINT)
 RETURNS SETOF RECORD AS
 'MODULE_PATHNAME'
-LANGUAGE c VOLATILE STRICT;
+LANGUAGE C VOLATILE STRICT
+COST ${COST_HIGH} ROWS ${ROWS_HIGH};
 
--- COMMENTS
 
 
 COMMENT ON FUNCTION _pgr_topologicalSort(TEXT)
