@@ -38,9 +38,9 @@ CREATE FUNCTION _pgr_transitiveClosure(
     OUT target_array BIGINT[])
 RETURNS SETOF RECORD AS
 'MODULE_PATHNAME'
-LANGUAGE c VOLATILE STRICT;
+LANGUAGE C VOLATILE STRICT
+COST ${COST_HIGH} ROWS ${ROWS_HIGH};
 
--- COMMENTS
 
 
 COMMENT ON FUNCTION _pgr_transitiveClosure(TEXT)
