@@ -4,7 +4,7 @@ Copyright (c) 2016 pgRouting developers
 Mail: project@pgrouting.org
 
 Copyright (c) 2016 Celia Virginia Vergara Castillo
-mail: vicky_vergara@hotmail.com
+mail: vicky at erosion.dev
 
 ------
 
@@ -24,40 +24,20 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
  ********************************************************************PGR-GNU*/
 
+--v4.0
+CREATE FUNCTION _pgr_TSP_v4(
+  TEXT,
+  BIGINT,
+  BIGINT,
 
--------------
--- tsp
--------------
-
-
---v3.0
-CREATE FUNCTION _pgr_TSP(
-    matrix_row_sql TEXT,
-    start_id BIGINT DEFAULT 0,
-    end_id BIGINT DEFAULT 0,
-
-    max_processing_time FLOAT DEFAULT '+infinity'::FLOAT,
-
-    tries_per_temperature INTEGER DEFAULT 500,
-    max_changes_per_temperature INTEGER DEFAULT 60,
-    max_consecutive_non_changes INTEGER DEFAULT 100,
-
-    initial_temperature FLOAT DEFAULT 100,
-    final_temperature FLOAT DEFAULT 0.1,
-    cooling_factor FLOAT DEFAULT 0.9,
-
-    randomize BOOLEAN DEFAULT true,
-
-    OUT seq INTEGER,
-    OUT node BIGINT,
-    OUT cost FLOAT,
-    OUT agg_cost FLOAT)
+  OUT seq INTEGER,
+  OUT node BIGINT,
+  OUT cost FLOAT,
+  OUT agg_cost FLOAT)
 RETURNS SETOF record
 AS 'MODULE_PATHNAME'
-LANGUAGE c VOLATILE STRICT;
+LANGUAGE C VOLATILE STRICT
+COST ${COST_HIGH} ROWS ${ROWS_HIGH};
 
-
--- COMMENTS
-
-COMMENT ON FUNCTION _pgr_TSP(TEXT, BIGINT, BIGINT, FLOAT, INTEGER, INTEGER, INTEGER, FLOAT, FLOAT, FLOAT, BOOLEAN)
+COMMENT ON FUNCTION _pgr_TSP_v4(TEXT, BIGINT, BIGINT)
 IS 'pgRouting internal function';
