@@ -30,7 +30,8 @@ RETURNS TEXT AS
 $BODY$
     SELECT '${PROJECT_VERSION}${PROJECT_VERSION_DEV}'::varchar AS pgr_version;
 $BODY$
-LANGUAGE sql IMMUTABLE;
+LANGUAGE sql IMMUTABLE
+COST 1;
 
 COMMENT ON FUNCTION pgr_version() IS
 'pgr_version
