@@ -39,8 +39,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 #include "drivers/yen/ksp_driver.h"
 
-PGDLLEXPORT Datum _pgr_ksp(PG_FUNCTION_ARGS);
-PG_FUNCTION_INFO_V1(_pgr_ksp);
+PGDLLEXPORT Datum _pgr_ksp_v4(PG_FUNCTION_ARGS);
+PG_FUNCTION_INFO_V1(_pgr_ksp_v4);
 
 static
 void
@@ -95,6 +95,122 @@ process(
     pgr_SPI_finish();
 }
 
+PGDLLEXPORT Datum
+_pgr_ksp_v4(PG_FUNCTION_ARGS) {
+    FuncCallContext     *funcctx;
+    TupleDesc            tuple_desc;
+    Path_rt      *path = NULL;
+
+    size_t result_count = 0;
+
+    if (SRF_IS_FIRSTCALL()) {
+        MemoryContext   oldcontext;
+        funcctx = SRF_FIRSTCALL_INIT();
+        oldcontext = MemoryContextSwitchTo(funcctx->multi_call_memory_ctx);
+
+        if (PG_NARGS() == 6) {
+            /*
+             * many to many
+             */
+            process(
+                text_to_cstring(PG_GETARG_TEXT_P(0)),
+                NULL,
+                PG_GETARG_ARRAYTYPE_P(1),
+                PG_GETARG_ARRAYTYPE_P(2),
+                NULL, NULL,
+                PG_GETARG_INT32(3),
+                PG_GETARG_BOOL(4),
+                PG_GETARG_BOOL(5),
+                &path,
+                &result_count);
+        } else if (PG_NARGS() == 5) {
+            /*
+             * combinations
+             */
+            process(
+                text_to_cstring(PG_GETARG_TEXT_P(0)),
+                text_to_cstring(PG_GETARG_TEXT_P(1)),
+                NULL, NULL,
+                NULL, NULL,
+                PG_GETARG_INT32(2),
+                PG_GETARG_BOOL(3),
+                PG_GETARG_BOOL(4),
+                &path,
+                &result_count);
+        }
+
+        funcctx->max_calls = result_count;
+        funcctx->user_fctx = path;
+        if (get_call_result_type(fcinfo, NULL, &tuple_desc) != TYPEFUNC_COMPOSITE) {
+            ereport(ERROR,
+                    (errcode(ERRCODE_FEATURE_NOT_SUPPORTED),
+                     errmsg("function returning record called in context that cannot accept type record")));
+        }
+
+        funcctx->tuple_desc = tuple_desc;
+        MemoryContextSwitchTo(oldcontext);
+    }
+
+    funcctx = SRF_PERCALL_SETUP();
+    tuple_desc = funcctx->tuple_desc;
+    path = (Path_rt*) funcctx->user_fctx;
+
+    if (funcctx->call_cntr < funcctx->max_calls) {
+        HeapTuple    tuple;
+        Datum        result;
+        Datum        *values;
+        bool*        nulls;
+
+        size_t n = 9;
+        values = palloc(n * sizeof(Datum));
+        nulls = palloc(n * sizeof(bool));
+
+        size_t i;
+        for (i = 0; i < n; ++i) {
+            nulls[i] = false;
+        }
+
+        int64_t path_id = 1;
+        if (funcctx->call_cntr != 0) {
+            if (path[funcctx->call_cntr - 1].edge == -1) {
+                path_id = path[funcctx->call_cntr - 1].start_id + 1;
+            } else {
+                path_id = path[funcctx->call_cntr - 1].start_id;
+            }
+        }
+        int64_t seq = funcctx->call_cntr == 0?  1 : path[funcctx->call_cntr - 1].end_id;
+
+        values[0] = Int32GetDatum((int32_t)funcctx->call_cntr + 1);
+        values[1] = Int32GetDatum((int32_t)path_id);
+        values[2] = Int32GetDatum((int32_t)seq);
+        values[3] = Int64GetDatum(path[funcctx->call_cntr].start_id);
+        values[4] = Int64GetDatum(path[funcctx->call_cntr].end_id);
+        values[5] = Int64GetDatum(path[funcctx->call_cntr].node);
+        values[6] = Int64GetDatum(path[funcctx->call_cntr].edge);
+        values[7] = Float8GetDatum(path[funcctx->call_cntr].cost);
+        values[8] = Float8GetDatum(path[funcctx->call_cntr].agg_cost);
+
+        path[funcctx->call_cntr].start_id = path_id;
+        path[funcctx->call_cntr].end_id = path[funcctx->call_cntr].edge < 0? 1 : seq + 1;
+
+        tuple = heap_form_tuple(tuple_desc, values, nulls);
+        result = HeapTupleGetDatum(tuple);
+        SRF_RETURN_NEXT(funcctx, result);
+    } else {
+        SRF_RETURN_DONE(funcctx);
+    }
+}
+
+/* Deprecated code starts here
+ * This code is used on v3.5 and under
+ *
+ * TODO(v4.2) define SHOWMSG
+ * TODO(v4.3) change to WARNING
+ * TODO(v5) Move to legacy
+ */
+PGDLLEXPORT Datum _pgr_ksp(PG_FUNCTION_ARGS);
+PG_FUNCTION_INFO_V1(_pgr_ksp);
+
 PGDLLEXPORT Datum
 _pgr_ksp(PG_FUNCTION_ARGS) {
     FuncCallContext     *funcctx;
@@ -108,6 +224,14 @@ _pgr_ksp(PG_FUNCTION_ARGS) {
         funcctx = SRF_FIRSTCALL_INIT();
         oldcontext = MemoryContextSwitchTo(funcctx->multi_call_memory_ctx);
 
+#ifdef SHOWMSG
+        ereport(NOTICE, (
+                    errcode(ERRCODE_WARNING_DEPRECATED_FEATURE),
+                    errmsg("A stored procedure is using deprecated C internal function '%s'", __func__),
+                    errdetail("Library function '%s' was deprecated in pgRouting %s", __func__, "4.0.0"),
+                    errhint("Consider upgrade pgRouting")));
+#endif
+
         if (PG_NARGS() == 7) {
             /*
              * many to many
