@@ -177,6 +177,7 @@ createTestDB($DBNAME);
 
 # Load the sample data & any other relevant data files
 mysystem("$psql $connopts -A -t -q -f tools/testers/sampledata.sql $DBNAME >> $TMP2 2>\&1 ");
+mysystem("$psql $connopts -A -t -q -f tools/testers/lc101.pg $DBNAME >> $TMP2 2>\&1 ");
 
 if ($DATA) {exit 0;};
 
@@ -273,6 +274,7 @@ sub process_single_test{
 
     # Load the sample data & any other relevant data files
     mysystem("$psql $connopts -A -t -q -f tools/testers/sampledata.sql $DBNAME >> $TMP2 2>\&1 ");
+    mysystem("$psql $connopts -A -t -q -f tools/testers/lc101.pg $DBNAME >> $TMP2 2>\&1 ");
 
     # TIN = test input file
     open(TIN, "$inputFile") || do {
@@ -312,7 +314,7 @@ sub process_single_test{
 
     print PSQL "BEGIN;\n";
     print PSQL "SET client_min_messages TO $LEVEL;\n";
-    # prints the whole fle stored in @queries
+    # prints the whole file stored in @queries
     print PSQL @queries;
     print PSQL "\nROLLBACK;";
 
@@ -381,7 +383,7 @@ sub createTestDB {
 
     die "
     Unsupported postgreSQL version $dbver
-    Minimum requierment is $POSGRESQL_MIN_VERSION version
+    Minimum requirement is $POSGRESQL_MIN_VERSION version
     Use -force to force the tests\n"
     unless version_greater_eq($dbver, $POSGRESQL_MIN_VERSION);
 
@@ -473,7 +475,7 @@ sub findPsql {
 }
 
 # getSharePath is complicated by the fact that on Debian we can have multiple
-# versions installed in a cluster. So we get the DB version by connectiong
+# versions installed in a cluster. So we get the DB version by connection,
 # to the port for the server we want. Then we get the share path for the
 # newest version od pg installed on the cluster. And finally we change the
 # in the path to the version of the server.
